Graffiti
========

Simple app using the Graffiti
`model <https://huggingface.co/artificialhoney/graffiti>`__ and
**giger**.

Installation
------------

``pip install -r requirements.txt``

Usage
-----

``streamlit run app.py``
